<?php
/**
 * Plugin Name: AEA - Widgets
 * Plugin URI:
 * Description: Añade Widgets personalizados a la web de AEA - Ayuda En Acción
 * Version: 1.0.0
 * Author: Jhonny Gómez (JonnyGO)
 * Author URI: https://www.jhonnygo.com
 * Text Domain: aea_pt
 */

// Seguridad
if (!defined('ABSPATH')) die();

/**
 * Adds AEA_Widget widget.
 */
class AEA_Widget extends WP_Widget
{

    /**
     * Register widget with WordPress.
     */
    function __construct()
    {
        parent::__construct(
            'aea_widget', // Base ID
            esc_html__('AEA Últimos Artículos', 'aea_pt'), // Name
            array('description' => esc_html__('Agrega los últimos artículos como Widget', 'aea_pt'),) // Args
        );
    }

    /**
     * Front-end display of widget.
     *
     * @param array $args Widget arguments.
     * @param array $instance Saved values from database.
     * @see WP_Widget::widget()
     *
     */
    public function widget($args, $instance)
    {
        echo $args['before_widget'];
        if (!empty($instance['title'])) {
            echo $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        }
        //echo esc_html__( 'Hola Mundo', 'aea_es' );

        $titulo = $instance['titulo'];
        $entradaTipo = $instance['entradaTipo'];
        $cantidad = $instance['cantidad'];
        $entradaOrden = $instance['entradaOrden'];
        ?>

        <div class="lista-articulos-sb-blog-titulo">
            <h3 class="linea-no-animada"><?php echo $titulo; ?></h3>
        </div>

        <ul class="lista-articulos-sb-blog">
            <?php
            $args = [
                'post_type' => $entradaTipo,
                'posts_per_page' => $cantidad,
                'orderby' => $entradaOrden
                // 'order_by' => 'title',
                // 'order' => 'ASC'
            ];

            $articulos = new WP_Query($args);

            while ($articulos->have_posts()):
                $articulos->the_post();

                $entradaFechaArticulo = get_the_date('d-m-Y');
                ?>

                <li class="contenedor-sb-blog-articulos">
                    <div class="imagen">
                        <a href="<?php the_permalink(); ?>">
                            <?php the_post_thumbnail('blog-xs-97x97'); ?>
                        </a>
                    </div>

                    <div class="contenido">
                        <a href="<?php the_permalink(); ?>" title="<?php echo the_title(); ?>">
                            <h3><?php echo wp_trim_words( get_the_title(), 10 ); ?></h3>
                        </a>
                        <div class="info">
                            <img src="<?php echo get_stylesheet_directory_uri(); ?>/img/blog-2019/iconos/calendario.png">
                            <span><?php echo $entradaFechaArticulo; ?></span>
                        </div>
                    </div>
                </li>

            <?php endwhile;
            wp_reset_postdata(); ?>

        </ul>

        <?php
        //echo $args['after_widget'];
    }

    /**
     * Back-end widget form.
     *
     * @param array $instance Previously saved values from database.
     * @see WP_Widget::form()
     *
     */
    public function form($instance)
    {
        $titulo = !empty($instance['titulo']) ? $instance['titulo'] : esc_html__('Indique un Titulo', 'aea_es');
        $entradaTipo = !empty($instance['entradaTipo']) ? $instance['entradaTipo'] : esc_html__('Seleccione el tipo de entrada', 'aea_es');
        $cantidad = !empty($instance['cantidad']) ? $instance['cantidad'] : esc_html__('¿Cuántos artículos deseas mostrar?', 'aea_es');
        $entradaOrden = !empty($instance['entradaOrden']) ? $instance['entradaOrden'] : esc_html__('Seleccione el orden de los artículos', 'aea_es');
        ?>

        <!-- TITULO -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('titulo') ); ?>"></label>
            <input
                class="widefat" id="<?php echo esc_attr( $this->get_field_name('titulo') ); ?>"
                name="<?php echo esc_attr( $this->get_field_name('titulo') ); ?>"
                value="<?php esc_attr_e($titulo); ?>"
                type="text">
        </p>

        <!-- TIPO DE POST -->
        <p>
            <?php //$post_types = get_post_types(); ?>
            <label for="<?php echo esc_attr( $this->get_field_id('entradaTipo') ); ?>">
                <?php esc_attr_e('Indique el tipo de entrada', 'aea_es') ?>
            </label>
            <select
                class="widefat" id="<?php echo esc_attr( $this->get_field_name('entradaTipo') ); ?>"
                name="<?php echo esc_attr( $this->get_field_name('entradaTipo') ); ?>" id="">

                <?php foreach ( get_post_types( '', 'names' ) as $post_type ) { ?>
                    <option value="<?php echo $post_type; ?>" <?php if( esc_attr_e($entradaTipo) == $post_type ){echo 'selected';} ?>><?php echo $post_type; ?></option>
                <?php } ?>
            </select>
        </p>

        <!-- CANTIDAD DE ARTICULOS -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('cantidad') ); ?>">
                <?php esc_attr_e('¿Cuántos artículos deseas mostrar?', 'aea_es') ?>
            </label>
            <input
                class="widefat" id="<?php echo esc_attr( $this->get_field_name('cantidad') ); ?>"
                name="<?php echo esc_attr( $this->get_field_name('cantidad') ); ?>"
                value="<?php esc_attr_e($cantidad); ?>"
                type="number">
        </p>


        <!-- ORDEN DE LOS ARTICULOS -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('entradaOrden') ); ?>">
                <?php esc_attr_e('Indique el orden de los articulos', 'aea_es') ?>
            </label>
            <select
                class="widefat" id="<?php echo esc_attr( $this->get_field_name('entradaOrden') ); ?>"
                name="<?php echo esc_attr( $this->get_field_name('entradaOrden') ); ?>" id="">

                <option value="desc" <?php if( esc_attr_e($entradaOrden) == 'desc' ){echo 'selected';} ?>>DESCENDENTE</option>
                <option value="asc" <?php if( esc_attr_e($entradaOrden) == 'asc' ){echo 'selected';} ?>>ASCENDENTE</option>
                <option value="rand" <?php if( esc_attr_e($entradaOrden) == 'rand' ){echo 'selected';} ?>>ALEATORIO</option>

            </select>
        </p>


        <?php
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     * @see WP_Widget::update()
     *
     */
    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['titulo'] = (!empty($new_instance['titulo'])) ? sanitize_text_field($new_instance['titulo']) : '';
        $instance['entradaTipo'] = (!empty($new_instance['entradaTipo'])) ? sanitize_text_field($new_instance['entradaTipo']) : '';
        $instance['cantidad'] = (!empty($new_instance['cantidad'])) ? sanitize_text_field($new_instance['cantidad']) : '';
        $instance['entradaOrden'] = (!empty($new_instance['entradaOrden'])) ? sanitize_text_field($new_instance['entradaOrden']) : '';
        return $instance;
    }

} // class AEA_Widget


// register AEA_Widget widget
function register_aea_widget()
{
    register_widget('AEA_Widget');
}

add_action('widgets_init', 'register_aea_widget');
